@@ -48,9 +48,9 @@ class ActivityDirector(threading.local):
         return self.node_manager.is_following(follower, following)
 
     def create_activity(self, actor, verb, obj, target=None,
-            related_nodes=None):
+            related_nodes=None, tags=None):
         return self.activity_manager.create(actor, verb, obj, target=target,
-                related_nodes=related_nodes)
+                related_nodes=related_nodes, tags=tags)
 
     def create_timeline(self, node_id):
         """Create an up-to-date timeline for the ``node_id`` Node.
