@@ -76,7 +76,7 @@ class ActivityManager(base.ActivityManagerBase):
         self.storage = storage
         self.node_manager = node_manager
 
-    def create(self, actor, verb, obj, target=None, related_nodes=None):
+    def create(self, actor, verb, obj, target=None, related_nodes=None, tags=None):
         """Create and serialize an :class:`Activity`.
 
         Serializing includes making a copy of the activity for any node in the
@@ -86,8 +86,9 @@ class ActivityManager(base.ActivityManagerBase):
         related_nodes = related_nodes or []
         owners = [
                 node.node_id for node in [actor, obj, target] + related_nodes
-                if hasattr(node, 'node_id')]
+                if getattr(node, 'node_id', None)]
 
+        activity = None
         for owner in owners:
             activity = StoredActivity(
                     actor=actor,
@@ -95,7 +96,8 @@ class ActivityManager(base.ActivityManagerBase):
                     obj=obj,
                     target=target,
                     published=datetime.datetime.utcnow(),
-                    node_id = owner
+                    node_id=owner,
+                    tags=tags,
                     )
             self.storage.save_activity(activity)
         return activity
