@@ -46,9 +46,6 @@ class StoredActivity(ActivityBase):
     """
     def __init__(self, **kw):
         super(StoredActivity, self).__init__()
-        self.score = None
-        self.owner_id = None
-        self.node_id = None
         for k, v in kw.iteritems():
             if k in ('actor', 'obj', 'target') and isinstance(v, dict):
                 v = ActivityObject(**v)
@@ -62,9 +59,10 @@ class StoredActivity(ActivityBase):
                 obj=ActivityObject.to_dict(self.obj),
                 target=ActivityObject.to_dict(self.target),
                 published=self.published,
-                node_id=self.node_id,
-                owner_id=self.owner_id,
-                score=self.score,
+                node_id=getattr(self, 'node_id', None),
+                owner_id=getattr(self, 'owner_id', None),
+                score=getattr(self, 'score', None),
+                tags=getattr(self, 'tags', None),
                 )
         d.update(kw)
         return d
